# Express Pascal Voc Tools

A tool for creating, reading and visualizing Pascal VOC annotations

# Getting Started

## Install

`pip install express-pascal-voc-tools`

## VOC Reading

# Collaborate

GitHub: [https://github.com/Redcof/pascal_voc_tools.git](https://github.com/Redcof/pascal_voc_tools.git)

## Build and Publish

`python setup.py sdist bdist_wheel`
`python -m twine upload dist/*`